==> junitperf_1.6.orig.tar.gz: junitperf-1.6.orig/src/app/com/clarkware/junitperf/ThreadedTestGroup.java <==
package com.clarkware.junitperf;

import junit.framework.AssertionFailedError;
import junit.framework.Test;
import junit.framework.TestResult;

/**
 * The <code>ThreadedTestGroup</code> is a <code>ThreadGroup</code>
 * that catches and handles exceptions thrown by threads created 
 * and started by <code>ThreadedTest</code> instances.
 * <p>
 * If a thread managed by a <code>ThreadedTestGroup</code> throws 
 * an uncaught exception, then the exception is added to the current 
 * test's results and all other threads are immediately interrupted.
 *
 * @author Ervin Varga
 * @author <a href="mailto:mike@clarkware.com">Mike Clark</a>
 * @author <a href="http://www.clarkware.com">Clarkware Consulting, Inc.</a>
 *
 * @see java.lang.ThreadGroup
 */

public class ThreadedTestGroup extends ThreadGroup {

	private final Test _test;
	private TestResult _testResult;
	
	/**
	 * Constructs a <code>ThreadedTestGroup</code> for the
	 * specified test.
	 *
	 * @param test Current test.
	 */
	public ThreadedTestGroup(Test test) {
		super("ThreadedTestGroup");
		_test = test;
	}
	
	/**
	 * Sets the current test result.
	 *
	 * @param result Test result.
	 */
	public void setTestResult(TestResult result) {
		_testResult = result;
	}

	/**
	 * Called when a thread in this thread group stops because of
	 * an uncaught exception.
	 * <p>
	 * If the uncaught exception is a <code>ThreadDeath</code>,
	 * then it is ignored.  If the uncaught exception is an
	 * <code>AssertionFailedError</code>, then a failure
	 * is added to the current test result.  Otherwise, an
	 * error is added to the current test result.
	 *
	 * @param t Originating thread.
	 * @param e Uncaught exception.
	 */
	public void uncaughtException(Thread t, Throwable e) {
		
		if (e instanceof ThreadDeath) {
			return;
		}
		
		if (e instanceof AssertionFailedError) {
			_testResult.addFailure(_test, (AssertionFailedError)e);
		} else {
			_testResult.addError(_test, e);
		}
		
		super.interrupt();
	}
}

==> junitperf_1.8.orig.tar.gz: junitperf-1.8.orig/src/app/com/clarkware/junitperf/ThreadedTestGroup.java <==
package com.clarkware.junitperf;

import junit.framework.AssertionFailedError;
import junit.framework.Test;
import junit.framework.TestResult;

/**
 * The <code>ThreadedTestGroup</code> is a <code>ThreadGroup</code>
 * that catches and handles exceptions thrown by threads created 
 * and started by <code>ThreadedTest</code> instances.
 * <p>
 * If a thread managed by a <code>ThreadedTestGroup</code> throws 
 * an uncaught exception, then the exception is added to the current 
 * test's results and all other threads are immediately interrupted.
 * </p>
 * @author Ervin Varga
 * @author <a href="mailto:mike@clarkware.com">Mike Clark</a>
 * @author <a href="http://www.clarkware.com">Clarkware Consulting, Inc.</a>
 *
 * @see java.lang.ThreadGroup
 */

public class ThreadedTestGroup extends ThreadGroup {

	private final Test _test;
	private TestResult _testResult;
	
	/**
	 * Constructs a <code>ThreadedTestGroup</code> for the
	 * specified test.
	 *
	 * @param test Current test.
	 */
	public ThreadedTestGroup(Test test) {
		super("ThreadedTestGroup");
		_test = test;
	}
	
	/**
	 * Sets the current test result.
	 *
	 * @param result Test result.
	 */
	public void setTestResult(TestResult result) {
		_testResult = result;
	}

	/**
	 * Called when a thread in this thread group stops because of
	 * an uncaught exception.
	 * <p>
	 * If the uncaught exception is a <code>ThreadDeath</code>,
	 * then it is ignored.  If the uncaught exception is an
	 * <code>AssertionFailedError</code>, then a failure
	 * is added to the current test's result.  Otherwise, an
	 * error is added to the current test's result.
	 *
	 * @param t Originating thread.
	 * @param e Uncaught exception.
	 */
	public void uncaughtException(Thread t, Throwable e) {
		
		if (e instanceof ThreadDeath) {
			return;
		}
		
		if (e instanceof AssertionFailedError) {
			_testResult.addFailure(_test, (AssertionFailedError)e);
		} else {
			_testResult.addError(_test, e);
		}
		
		super.interrupt();
	}
}
